import { AuthenticationServiceSignatures, BookingServiceSignatures, DeviceServiceSignatures, ExperimentServiceSignatures, FederationServiceSignatures, UpdateServiceSignatures } from './signatures';
import { ResponseData, AuthenticationServiceTypes, BookingServiceTypes, DeviceServiceTypes, ExperimentServiceTypes, FederationServiceTypes, UpdateServiceTypes } from './types';
/**
 * This error class should be used if an error occurs during validation of a request/response.
 * @category Errors
 */
export declare class ValidationError extends Error {
    errors: any;
    constructor(message: string, errors: any);
}
/**
 * This error class should be used if an error occurs while fetching a request.
 * @category Errors
 */
export declare class FetchError extends Error {
    constructor(message: string);
}
/**
 * This error class should be used if the response of the server has a status
 * greater than or equal to 400. This error should contain the validated response.
 * @category Errors
 */
export declare class UnsuccessfulRequestError extends Error {
    response: ResponseData;
    constructor(message: string, response: ResponseData);
}
/**
 * This error class should be used if the validation of an url fails.
 * @category Errors
 */
export declare class InvalidUrlError extends Error {
    constructor(message: string);
}
/**
 * Client for the use of the Crosslab API
 * @category Client
 */
export declare class APIClient {
    private _url;
    private _accessToken;
    private fetch;
    /**
     * @category Constructors
     */
    constructor(url: string, accessToken?: string);
    /**
     * @category Accessors
     */
    get url(): string;
    /**
     * @category Accessors
     */
    set url(url: string);
    /**
     * @category Accessors
     */
    set accessToken(accessToken: string);
    /**
     * @category Accessors
     */
    get accessToken(): string;
    /**
     * Login user
     *
     * @param username
     * Username of the user.
     * @param password
     * Password of the user.
     * @param options.method
     * Authentication method.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Return the access token.
     *
     * @category Authentication Service Methods
     */
    login(username: string, password: string, options?: {
        method?: 'tui' | 'local';
    }): Promise<void>;
    /**
     * Logout user
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Successfully logged out the user.
     *
     * @category Authentication Service Methods
     */
    logout(): Promise<void>;
    /**
     * Create a device authentication token
     *
     * @param device_url
     * Url of the device.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The created device authentication token.
     *
     * @category Authentication Service Methods
     */
    createDeviceAuthenticationToken(device_url: string): Promise<AuthenticationServiceSignatures.CreateDeviceAuthenticationTokenSuccessResponse['body']>;
    /**
     * Get all users
     *
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON representation of the users.
     *
     * @category Authentication Service Methods
     */
    listUsers(options?: {
        url?: string;
    }): Promise<AuthenticationServiceSignatures.ListUsersSuccessResponse['body']>;
    /**
     * Create a user
     *
     * @param user
     * User to be created.
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON representation of the created user.
     *
     * @category Authentication Service Methods
     */
    createUser(user: AuthenticationServiceTypes.User<'request'>, options?: {
        url?: string;
    }): Promise<AuthenticationServiceSignatures.CreateUserSuccessResponse['body']>;
    /**
     * Get a user
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON respresentation of the user.
     *
     * @category Authentication Service Methods
     */
    getUser(url: string): Promise<AuthenticationServiceSignatures.GetUserSuccessResponse['body']>;
    /**
     * Update a user
     *
     * @param url
     * Url of the resource to be accessed.
     * @param userUpdate
     * Updated user
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON representation of the updated user.
     *
     * @category Authentication Service Methods
     */
    updateUser(url: string, userUpdate: AuthenticationServiceTypes.UserUpdate<'request'>): Promise<AuthenticationServiceSignatures.UpdateUserSuccessResponse['body']>;
    /**
     * Delete a user
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * User deleted successfully
     *
     * @category Authentication Service Methods
     */
    deleteUser(url: string): Promise<void>;
    /**
     * Get roles of user
     *
     * @param user_id
     * ID of a user.
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Roles successfully retrieved.
     *
     * @category Authentication Service Methods
     */
    getRolesOfUser(user_id: string, options?: {
        url?: string;
    }): Promise<AuthenticationServiceSignatures.GetRolesOfUserSuccessResponse['body']>;
    /**
     * Add roles to user
     *
     * @param body
     * Roles to be added to the user.
     * @param user_id
     * ID of a user.
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Roles added successfully.
     *
     * @category Authentication Service Methods
     */
    addRolesToUser(body: string[], user_id: string, options?: {
        url?: string;
    }): Promise<void>;
    /**
     * Remove roles from user
     *
     * @param body
     * Roles to be removed from the user.
     * @param user_id
     * ID of a user.
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Roles removed successfully.
     *
     * @category Authentication Service Methods
     */
    removeRolesFromUser(body: string[], user_id: string, options?: {
        url?: string;
    }): Promise<void>;
    /**
     * Get all roles
     *
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON representation of the roles.
     *
     * @category Authentication Service Methods
     */
    listRoles(options?: {
        url?: string;
    }): Promise<AuthenticationServiceSignatures.ListRolesSuccessResponse['body']>;
    /**
     * Create a role
     *
     * @param role
     * Role to be created.
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON representation of the created role.
     *
     * @category Authentication Service Methods
     */
    createRole(role: AuthenticationServiceTypes.Role<'request'>, options?: {
        url?: string;
    }): Promise<AuthenticationServiceSignatures.CreateRoleSuccessResponse['body']>;
    /**
     * Get a role
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON respresentation of the role.
     *
     * @category Authentication Service Methods
     */
    getRole(url: string): Promise<AuthenticationServiceSignatures.GetRoleSuccessResponse['body']>;
    /**
     * Update a role
     *
     * @param url
     * Url of the resource to be accessed.
     * @param role
     * Updated role
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON representation of the updated role.
     *
     * @category Authentication Service Methods
     */
    updateRole(url: string, role: AuthenticationServiceTypes.Role<'request'>): Promise<AuthenticationServiceSignatures.UpdateRoleSuccessResponse['body']>;
    /**
     * Delete a role
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Role deleted successfully
     *
     * @category Authentication Service Methods
     */
    deleteRole(url: string): Promise<void>;
    /**
     * Get users with role
     *
     * @param role_id
     * ID of a role.
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Users successfully retrieved.
     *
     * @category Authentication Service Methods
     */
    getUsersWithRole(role_id: string, options?: {
        url?: string;
    }): Promise<AuthenticationServiceSignatures.GetUsersWithRoleSuccessResponse['body']>;
    /**
     * Add users to role
     *
     * @param body
     * Users to be added to the role.
     * @param role_id
     * ID of a role.
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Users added successfully.
     *
     * @category Authentication Service Methods
     */
    addUsersToRole(body: string[], role_id: string, options?: {
        url?: string;
    }): Promise<void>;
    /**
     * Remove users from role
     *
     * @param body
     * Users to be removed from the role.
     * @param role_id
     * ID of a role.
     * @param options.url
     * Url of the Authentication Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Users removed successfully.
     *
     * @category Authentication Service Methods
     */
    removeUsersFromRole(body: string[], role_id: string, options?: {
        url?: string;
    }): Promise<void>;
    /**
     * Get identity
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON representation of the corresponding user.
     *
     * @category Authentication Service Methods
     */
    getIdentity(): Promise<AuthenticationServiceSignatures.GetIdentitySuccessResponse['body']>;
    /**
     * Update identity
     *
     * @param userUpdate
     * Updated identity.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON representation of the updated user.
     *
     * @category Authentication Service Methods
     */
    updateIdentity(userUpdate: AuthenticationServiceTypes.UserUpdate<'request'>): Promise<AuthenticationServiceSignatures.UpdateIdentitySuccessResponse['body']>;
    /**
     * Register user
     *
     * @param body
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * User successfully registered.
     *
     * @category Authentication Service Methods
     */
    register(body: AuthenticationServiceTypes.Credentials<'request'> & {
        [k: string]: unknown;
    }): Promise<void>;
    /**
     * Returns the free / booked times for given experiment.
     *
     * @param scheduleRequest
     * Requested experiment and timeframe.
     * @param options.url
     * Url of the Booking Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Timetable of free/booked time. If 'Combined' is set to true, an array with only one entry is returned containing the combined timetable.
     *
     * @category Booking Service Methods
     */
    getSchedule(scheduleRequest: {
        /**
         * An experiment describes a set of devices and how they should be connected (potentially among other metadata).
         */
        Experiment: BookingServiceTypes.Experiment<'request'>;
        /**
         * A time slot represents a slice of time used for bookings.
         */
        Time: BookingServiceTypes.Timeslot<'request'>;
        /**
         * If true, show only one timetable per device instead of one for all available physical devices.
         */
        Combined?: boolean;
        /**
         * (private) Show only devices of this institution. Give an error if a device of an other institution is requested.
         */
        onlyOwn?: boolean;
        [k: string]: unknown;
    }, options?: {
        url?: string;
    }): Promise<BookingServiceSignatures.GetScheduleSuccessResponse['body']>;
    /**
     * Books an experiment.
     *
     * @param bookingRequest
     * Experiment, timeframe and type of booking.
     * @param options.url
     * Url of the Booking Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The booking was accepted. The booking status will display whether the booking of all devices was successful.
     *
     * @category Booking Service Methods
     */
    bookExperiment(bookingRequest: {
        /**
         * An experiment describes a set of devices and how they should be connected (potentially among other metadata).
         */
        Experiment: BookingServiceTypes.Experiment<'request'>;
        /**
         * A time slot represents a slice of time used for bookings.
         */
        Time: BookingServiceTypes.Timeslot<'request'>;
        /**
         * Type of booking. Currently, only one type is defined, but others might follow (e.g. priority booking). If empty, 'normal' is assumed.
         */
        Type?: 'normal';
        [k: string]: unknown;
    }, options?: {
        url?: string;
    }): Promise<BookingServiceSignatures.BookExperimentSuccessResponse['body']>;
    /**
     * Allows the addition of devices to a booking (removing of devices is not supportet) or the registration of callbacks.
     *
     * @param url
     * Url of the resource to be accessed.
     * @param devicesOrCallback
     * Devices or callback to be added to the booking.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The booking change was accepted. The booking status will display whether the booking of all devices was successful.
     *
     * @category Booking Service Methods
     */
    updateBooking(url: string, devicesOrCallback: {
        /**
         * Expresses whether the devices should be locked. Must match current status of booking.
         */
        Locked?: boolean;
        /**
         * List of devices which should be added.
         */
        Devices?: BookingServiceTypes.Device<'request'>[];
        [k: string]: unknown;
    } | {
        /**
         * Callback which should be called at changes.
         */
        Callback?: string;
        [k: string]: unknown;
    }): Promise<BookingServiceSignatures.UpdateBookingSuccessResponse['body']>;
    /**
     * Cancels a booking, as long as the booking was originally done by you.
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The booking was cancelled. All associated devices were released.
     *
     * @category Booking Service Methods
     */
    cancelBooking(url: string): Promise<void>;
    /**
     * Returns whether a list of devices is currently booked for a user
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Returns the current booking.
     *
     * @category Booking Service Methods
     */
    getBooking(url: string): Promise<BookingServiceSignatures.GetBookingSuccessResponse['body']>;
    /**
     * Allows selected persons (like lab manager) to remove a user booking. To avoid mistakes, this is a different path than normal delete.
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The booking was cancelled. All associated devices were released.
     *
     * @category Booking Service Methods
     */
    deleteBooking(url: string): Promise<void>;
    /**
     * Locks the current booking so the devices can be used. This sets the status to "active" This means that the booking can not be cancelled or (currently not implemented) the end time can not be set to a prior time. If called multiple times, the booking will be locked only once.
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * All devices were booked by user.
     *
     * @category Booking Service Methods
     */
    lockBooking(url: string): Promise<BookingServiceSignatures.LockBookingSuccessResponse['body']>;
    /**
     * Unlocks all devices belonging to a booking, status will be set to 'booked'.
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Unlocking was successful.
     *
     * @category Booking Service Methods
     */
    unlockBooking(url: string): Promise<void>;
    /**
     * List devices
     *
     * @param options.url
     * Url of the Device Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The list of all devices.
     *
     * @category Device Service Methods
     */
    listDevices(options?: {
        url?: string;
    }): Promise<DeviceServiceSignatures.ListDevicesSuccessResponse['body']>;
    /**
     * Create a new device
     *
     * @param device
     * The device to be created.
     * @param options.changedUrl
     * **An URL that will be called once the device changes.**
     *
     * Once the device was given a changedUrl parameter the contained URL will be called every time a device is changed
     * as long as every callback resolves with a successful status code.
     *
     * If the callback fails the url MIGHT not be called in the future.
     *
     * There can be multiple callbacks registered with the same device.
     * @param options.url
     * Url of the Device Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The device was created. A JSON representation of the new device is returned.
     *
     * @category Device Service Methods
     */
    createDevice(device: DeviceServiceTypes.Device<'request'>, options?: {
        changedUrl?: string;
        url?: string;
    }): Promise<DeviceServiceSignatures.CreateDeviceSuccessResponse['body']>;
    /**
     * View a registered device
     *
     * @param url
     * Url of the resource to be accessed.
     * @param options.flat_group
     * If true the returned device group will only contain concrete devices. I.e. any subgroups will be flattend.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON Representation of the device.
     *
     * @category Device Service Methods
     */
    getDevice(url: string, options?: {
        flat_group?: boolean;
    }): Promise<DeviceServiceSignatures.GetDeviceSuccessResponse['body']>;
    /**
     * Update an existing device
     *
     * @param url
     * Url of the resource to be accessed.
     * @param deviceUpdate
     * Updated device.
     * @param options.changedUrl
     * **An URL that will be called once the device changes.**
     *
     * Once the device was given a changedUrl parameter the contained URL will be called every time a device is changed
     * as long as every callback resolves with a successful status code.
     *
     * If the callback fails the url MIGHT not be called in the future.
     *
     * There can be multiple callbacks registered with the same device.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON Representation of the changed device.
     *
     * @category Device Service Methods
     */
    updateDevice(url: string, deviceUpdate: DeviceServiceTypes.DeviceUpdate<'request'>, options?: {
        changedUrl?: string;
    }): Promise<DeviceServiceSignatures.UpdateDeviceSuccessResponse['body']>;
    /**
     * Delete a registered device
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The device was deleted.
     *
     * @category Device Service Methods
     */
    deleteDevice(url: string): Promise<void>;
    /**
     * Instantiate a cloud instantiable device
     *
     * @param url
     * Url of the resource to be accessed.
     * @param options.changedUrl
     * **An URL that will be called once the device changes.**
     *
     * Once the device was given a changedUrl parameter the contained URL will be called every time a device is changed
     * as long as every callback resolves with a successful status code.
     *
     * If the callback fails the url MIGHT not be called in the future.
     *
     * There can be multiple callbacks registered with the same device.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON Representation of the created instance.
     *
     * @category Device Service Methods
     */
    instantiateDevice(url: string, options?: {
        changedUrl?: string;
    }): Promise<DeviceServiceSignatures.InstantiateDeviceSuccessResponse['body']>;
    /**
     * Update the device availability
     *
     * @param url
     * Url of the resource to be accessed.
     * @param availabilityRules
     * The availability rules to be applied.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON Representation of the changed availability.
     *
     * @category Device Service Methods
     */
    addAvailabilityRules(url: string, availabilityRules: DeviceServiceTypes.AvailabilityRule<'request'>[]): Promise<DeviceServiceSignatures.AddAvailabilityRulesSuccessResponse['body']>;
    /**
     * Create new websocket token for device
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The newly generated websocket token for the device.
     *
     * @category Device Service Methods
     */
    createWebsocketToken(url: string): Promise<DeviceServiceSignatures.CreateWebsocketTokenSuccessResponse['body']>;
    /**
     * Send signaling message to device
     *
     * @param url
     * Url of the resource to be accessed.
     * @param sigMessage
     * The signaling message to be sent.
     * @param peerconnection_url
     * URL of the peerconnection
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The signaling message was delivered successfully.
     *
     * @category Device Service Methods
     */
    sendSignalingMessage(url: string, sigMessage: DeviceServiceTypes.CreatePeerconnectionMessage<'request'> | DeviceServiceTypes.ClosePeerconnectionMessage<'request'> | DeviceServiceTypes.SignalingMessage<'request'>, peerconnection_url: string): Promise<void>;
    /**
     * List Peer Connection
     *
     * @param options.url
     * Url of the Device Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The list of all peerconnections.
     *
     * @category Device Service Methods
     */
    listPeerconnections(options?: {
        url?: string;
    }): Promise<DeviceServiceSignatures.ListPeerconnectionsSuccessResponse['body']>;
    /**
     * Create a new Peer Connection
     *
     * @param peerconnection
     * The peerconnection to be created.
     * @param options.closedUrl
     * An URL that will be called once the peer connection is closed.
     * @param options.statusChangedUrl
     * An URL that will be called if the status of the peerconnection changes.
     * @param options.url
     * Url of the Device Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * 201: The peerconnection was created. A JSON representation of the new peer connection is returned.
     * 202: The device service will attempt to create the peerconnection as soon as possible.
     *
     * @category Device Service Methods
     */
    createPeerconnection(peerconnection: DeviceServiceTypes.Peerconnection<'request'>, options?: {
        closedUrl?: string;
        statusChangedUrl?: string;
        url?: string;
    }): Promise<DeviceServiceSignatures.CreatePeerconnectionSuccessResponse['body']>;
    /**
     * View a peer connection
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON Representation of the device peer connection.
     *
     * @category Device Service Methods
     */
    getPeerconnection(url: string): Promise<DeviceServiceSignatures.GetPeerconnectionSuccessResponse['body']>;
    /**
     * Delete a peer connection
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The peer connection was deleted successfully.
     *
     * @category Device Service Methods
     */
    deletePeerconnection(url: string): Promise<void>;
    /**
     * Sets the peerconnection status of a single device.
     *
     * @param url
     * Url of the resource to be accessed.
     * @param body
     * The JSON Representation of the device peer connection.
     * @param device_url
     * URL of the device
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * OK.
     *
     * @category Device Service Methods
     */
    patchPeerconnectionDeviceStatus(url: string, body: {
        /**
         * The status of the peerconnection.
         */
        status: DeviceServiceTypes.ConnectionStatus<'request'>;
        [k: string]: unknown;
    }, device_url: string): Promise<void>;
    /**
     * List experiments
     *
     * @param options.url
     * Url of the Experiment Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The list of all experiments.
     *
     * @category Experiment Service Methods
     */
    listExperiments(options?: {
        url?: string;
    }): Promise<ExperimentServiceSignatures.ListExperimentsSuccessResponse['body']>;
    /**
     * Create a new experiment
     *
     * @param experiment
     * The experiment to be created.
     * @param options.url
     * Url of the Experiment Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * 201: The experiment was created. A JSON representation of the new experiment is returned.
     * 202: The experiment was created and will be set to running eventually. A JSON representation of the new experiment is returned.
     *
     * @category Experiment Service Methods
     */
    createExperiment(experiment: ExperimentServiceTypes.Experiment<'request'>, options?: {
        url?: string;
    }): Promise<ExperimentServiceSignatures.CreateExperimentSuccessResponse['body']>;
    /**
     * View an experiment.
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON Representation of the experiment
     *
     * @category Experiment Service Methods
     */
    getExperiment(url: string): Promise<ExperimentServiceSignatures.GetExperimentSuccessResponse['body']>;
    /**
     * Update an existing experiment.
     *
     * @param url
     * Url of the resource to be accessed.
     * @param experiment
     * Update the experiment
     * @param options.changedURL
     * An URL that will be called when the experiment status changes.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * 200: The JSON Representation of the changed experiment
     * 202: The JSON Representation of the changed experiment, that will be set to running eventually
     *
     * @category Experiment Service Methods
     */
    updateExperiment(url: string, experiment: ExperimentServiceTypes.Experiment<'request'>, options?: {
        changedURL?: string;
    }): Promise<ExperimentServiceSignatures.UpdateExperimentSuccessResponse['body']>;
    /**
     * Delete an experiment
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The experiment was deleted.
     *
     * @category Experiment Service Methods
     */
    deleteExperiment(url: string): Promise<void>;
    /**
     * List institutions
     *
     * @param options.url
     * Url of the Federation Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The list of all institutions.
     *
     * @category Federation Service Methods
     */
    listInstitutions(options?: {
        url?: string;
    }): Promise<FederationServiceSignatures.ListInstitutionsSuccessResponse['body']>;
    /**
     * Create a new institution
     *
     * @param institution
     * The institution to be created.
     * @param options.url
     * Url of the Federation Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The institution was created. A JSON representation of the new institution is returned.
     *
     * @category Federation Service Methods
     */
    createInstitution(institution: FederationServiceTypes.Institution<'request'>, options?: {
        url?: string;
    }): Promise<FederationServiceSignatures.CreateInstitutionSuccessResponse['body']>;
    /**
     * View an institution.
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON Representation of the institution
     *
     * @category Federation Service Methods
     */
    getInstitution(url: string): Promise<FederationServiceSignatures.GetInstitutionSuccessResponse['body']>;
    /**
     * Update an institution.
     *
     * @param url
     * Url of the resource to be accessed.
     * @param institution
     * Update the institution
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The JSON Representation of the changed institution
     *
     * @category Federation Service Methods
     */
    updateInstitution(url: string, institution: FederationServiceTypes.Institution<'request'>): Promise<FederationServiceSignatures.UpdateInstitutionSuccessResponse['body']>;
    /**
     * Delete an institution
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * The institution was delete.
     *
     * @category Federation Service Methods
     */
    deleteInstitution(url: string): Promise<void>;
    /**
     * Get update information for all devices
     *
     * @param options.url
     * Url of the Update Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * JSON representation of all update information
     *
     * @category Update Service Methods
     */
    listUpdates(options?: {
        url?: string;
    }): Promise<UpdateServiceSignatures.ListUpdatesSuccessResponse['body']>;
    /**
     * Create new update information
     *
     * @param updateInformation
     * The update to be created.
     * @param options.url
     * Url of the Update Service to be used.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * JSON representation of the new update
     *
     * @category Update Service Methods
     */
    createUpdate(updateInformation: UpdateServiceTypes.UpdateInformation<'request'>, options?: {
        url?: string;
    }): Promise<UpdateServiceSignatures.CreateUpdateSuccessResponse['body']>;
    /**
     * Get update for device
     *
     * @param url
     * Url of the resource to be accessed.
     * @param options.current_version
     * Current firmware version of the device
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * 200: Device is already up-to-date
     * 303: New version is available
     *
     * @category Update Service Methods
     */
    getUpdate(url: string, options?: {
        current_version?: string;
    }): Promise<void>;
    /**
     * Edit update information
     *
     * @param url
     * Url of the resource to be accessed.
     * @param updateInformation
     * Information regarding an update. Contains the id of the device,
     * the name of the latest version and a link to it.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Update information edited successfully
     *
     * @category Update Service Methods
     */
    patchUpdate(url: string, updateInformation: UpdateServiceTypes.UpdateInformation<'request'>): Promise<UpdateServiceSignatures.PatchUpdateSuccessResponse['body']>;
    /**
     * Delete update information
     *
     * @param url
     * Url of the resource to be accessed.
     *
     * @throws {@link FetchError | FetchError }
     * Thrown if fetch fails.
     * @throws {@link ValidationError | ValidationError }
     * Thrown if the request/response validation fails.
     * @throws {@link InvalidUrlError | InvalidUrlError }
     * Thrown if the provided url is not valid for this request.
     * @throws {@link UnsuccessfulRequestError | UnsuccessfulRequestError }
     * Thrown if response is validated but has status greater than or equal to 400.
     *
     * @returns
     * Update information was deleted successfully
     *
     * @category Update Service Methods
     */
    deleteUpdate(url: string): Promise<void>;
}
//# sourceMappingURL=client.d.ts.map